Welcome - pydagoras
Description: Documentation of the pydagoras package

Skip to content

# Welcome to pydagoras

## Introduction

pydagoras is a Python package to create a Directed Acyclical Graph DAG

## Package

pydagoras can be installed from PyPi, which can be reached using the Python link the bottom of this documentation. For further details see Package

## Example use

blah

## Demo

For further details see Demo blah

Was this page helpful?
Thanks for your feedback!
Thanks for your feedback! Help us improve this page by using our feedback form.